cheapr-package: cheapr: Simple Functions to Save Time and Memory

cheapr-packageR Documentation

cheapr: Simple Functions to Save Time and Memory

Description

In this package, 'cheap' means fast and efficient.

cheapr aims to provide a set of functions for programmers to write cheaper code, saving time and memory.

Author(s)

Maintainer: Nick Christofides nick.christofides.r@gmail.com (ORCID)

Authors:

See Also

Useful links:


cheapr documentation built on June 30, 2026, 5:10 p.m.